WidgetMediaItem class

Lightweight media attachment descriptor.

Constructors

WidgetMediaItem({required String url, String? name})
Creates a media descriptor with URL and optional filename.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
name String?
Optional display name for the asset.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String
Public URL of the media asset.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited